======
Readme
======

Uses quantum random numbers to generate a result from an n-numbered 'roll' from an n-sided die.

Links
-----

* GitHub: https://github.com/aubricus/pydie
* PyDie Readme: https://github.com/aubricus/pydie/blob/master/README.md
* Pydie License: https://github.com/aubricus/pydie/blob/master/LICENSE.md
* Pydie Todo: https://github.com/aubricus/pydie/blob/master/TODO.md
